#!/bin/bash
unset logscale x

set term postscript eps enhanced color
load 'output/logR0_cutoff_plot.txt'
load 'output/logsigma0_cutoff_plot.txt'
load 'output/kd_fit.txt'
set output 'plots/R0_sigma_V.eps'
set xrange [ -0.3 : 1.5 ]
set yrange [ 2.0 : 2.7 ]
set table 'test.dat'
splot 'output/dV_logR0_vs_logsimga_map.txt'
unset table
set pointsize 2
set xtics font ", 20" 
set ytics font ", 20" 
set xrange [ -0.3 : 1.5 ]
set yrange [ 2.0 : 2.7 ]
set xtics 0.25
set ytics 0.1
set xlabel " log_1_0(R_0 [kpc]) " font  ",24"
set ylabel " log_1_0({/Symbol s}_0 [km/s]) " font  ",24"
set key font ",20"
unset colorbox
set palette defined ( 0 '#FFFFFF',\
                      2 '#BBBBDD',\
                      4 '#9999BB',\
                      5 '#666688')
set arrow from -0.3 ,sigma_cut to 1.5 ,sigma_cut nohead ls 1 lt 4 front
set arrow from R0_cut,2.0 to R0_cut,2.7 nohead ls 1 lt 4 front
p 'test.dat' with image notitle,"output/cand_logR0_vs_logsimga.txt" with points lt 0 pt 3 title "candidates", x*kfit+dfit lt 4 notitle,"output/special_galaxy_Rsigma.txt"   with points lt rgb '#445566' pt 5 title "b19"

reset



set term postscript eps enhanced color
load 'output/logR0_cutoff_plot_sersic.txt'
load 'output/logsigma0_cutoff_plot_sersic.txt'
load 'output/kd_fit_sersic.txt'
set output 'plots/R0_sigma_S.eps'
set xrange [ -0.3 : 1.5 ]
set yrange [ 2.0 : 2.7 ]
set table 'test.dat'
splot 'output/sersic_logR0_vs_logsimga_map.txt'
unset table
set pointsize 2
set xtics font ", 20" 
set ytics font ", 20" 
set xrange [ -0.3 : 1.5 ]
set yrange [ 2.0 : 2.7 ]
set xtics 0.25
set ytics 0.1
set xlabel " log_1_0(R_0 [kpc]) " font  ",24"
set ylabel " log_1_0({/Symbol s}_0 [km/s]) " font  ",24"
set key font ",20"
unset colorbox
set palette defined ( 0 '#FFFFFF',\
                      2 '#BBBBDD',\
                      4 '#9999BB',\
                      5 '#666688')
set arrow from -0.3 ,sigma_cut_sersic to 1.5 ,sigma_cut_sersic nohead ls 1 lt 4 front
set arrow from R0_cut_sersic,2.0 to R0_cut_sersic,2.7 nohead ls 1 lt 4 front
p 'test.dat' with image notitle,"output/scand_logR0_sersic_vs_logsimga_sersic.txt" with points lt 0 pt 3 title "alt. candidates", x*kfit_sersic+dfit_sersic lt 4 notitle,"output/special_galaxy_Rsigma_sersic.txt"   with points lt rgb '#445566' pt 5 title "b19"


reset


# 
# 
# #-------------------------------------------------------------------

set term postscript eps enhanced color
set output 'plots/CMD.eps'
set xrange [ -24.75 : -20 ]
set yrange [ 0.5 : 1.2 ]
set table 'test.dat'
splot 'output/CMD_map.txt'
unset table
set pointsize 2
set xtics font ", 20" 
set ytics font ", 20" 
set mxtics 2
set mytics 2
set xrange [ -24.75 : -20 ]
set yrange [ 0.5 : 1.2 ]
set xtics 1
set ytics 0.2
set mxtics 2
set mytics 2
set xlabel " M_z [mag]" font  ",24"
set ylabel " g-r [mag]" font  ",24"
set key font ",20"
unset colorbox
set palette defined ( 0 '#FFFFFF',\
                      2 '#BBBBDD',\
                      4 '#9999BB',\
                      5 '#666688')
load 'input/redsequence_fit.txt'

p 'test.dat' with image notitle,"output/CMD_cand.txt" with points lt 0 pt 3 title "candidates","output/taylor_CMD.txt" with points lt 2 pt 9 title "  Ta10 sample","output/trujillo_CMD.txt"  with points lt 5  pt 13 title " Tr09 sample","output/special_galaxy_CMD.txt"   with points lt rgb '#445566' pt 5 title "b19", cc1*(x*x)+cc2*x+cc3  lt -1 title "red sequence fit", cc1*(x*x)+cc2*x+cc3+3*c_rms lt 1 title "3- {/Symbol s} interval", cc1*(x*x)+cc2*x+cc3-3*c_rms lt 1 notitle

reset



# -------------------------------------------------------------


set term postscript eps enhanced color 
set output 'plots/M_dyn_vs_R0_S.eps'

load 'output/logR0_cutoff_plot_sersic.txt'

set xrange [ 10.2 : 12.5 ]
set yrange [ -0.3 : 1.5 ]
set table 'test.dat'
splot 'output/R0_vs_M_dyn_map_S.txt'
unset table
set xrange [ 10.2 : 12.5 ]
set yrange [ -0.3 : 1.5 ]
set pointsize 2
set xtics font ", 20" 
set ytics font ", 20" 
set xtics 0.5
set ytics 0.25
set xlabel " log_1_0(M_d_y_n [M_{{/=12 O}&{/*-.45 O}{/=12 \267}} ]) " font  ",24"
set ylabel " log_1_0(R_0 [kpc])" font  ",24"
set key font ",20"
set key right
unset colorbox
set key bottom
set palette defined ( 0 '#FFFFFF',\
                      2 '#BBBBDD',\
                      4 '#9999BB',\
                      5 '#666688')
p 'test.dat' with image notitle,"output/scand_R0_sersic_vs_M_dyn_sersic.txt" with points lt 0 pt 3 title "alt. candidates","output/taylor_R0_sersic_vs_M_dyn_sersic.txt" with points lt 2 pt 9 title "  Ta10 sample","output/trujillo_R0_sersic_vs_M_dyn_sersic.txt"  with points lt 5  pt 13 title " Tr09 sample","output/special_R0_vs_M_dyn_sersic.txt"   with points lt rgb '#445566' pt 5 title "b19", R0_cut_sersic ls 1 lt 4 notitle


reset






# -------------------------------------------------------------




set term postscript eps enhanced color 
set output 'plots/fp_dV.eps'


load 'output/logR0_cutoff_plot.txt'
load 'output/fp_3rms.txt'
set xrange [ -0.4 : 1.5 ]
set yrange [ -0.4 : 1.5 ]
set table 'test.dat'
splot 'output/dV_fp_map.txt'
unset table
set pointsize 2
set xtics font ", 20" 
set ytics font ", 20" 
set xrange [ -0.4 : 1.5 ]
set yrange [ -0.4 : 1.5 ]
set xtics 0.25
set ytics 0.25
set xlabel " log_1_0(R_0) " font  ",24"
set ylabel " a log_1_0({/Symbol s}_0) + b log_1_0(I_0) + c" font  ",24"
set key font ",20"
set key right
unset colorbox
set key bottom
set palette defined ( 0 '#FFFFFF',\
                      2 '#BBBBDD',\
                      4 '#9999BB',\
                      5 '#666688')
set arrow from R0_cut,-0.3 to R0_cut,1.5 nohead ls 1 lt 4 front
p 'test.dat' with image notitle,"output/cand_fp.txt" with points lt 0 pt 3 title "candidates","output/taylor_fp.txt" with points lt 2 pt 9 title "  Ta10 sample","output/trujillo_fp.txt"  with points lt 5  pt 13 title " Tr09 sample","output/special_galaxy_FP.txt"   with points lt rgb '#445566' pt 5 title "b19", x lt 7 title 'fundamental plane', x+rms  lt 1 title "3- {/Symbol s} interval", x-rms  lt 1 notitle

unset arrow

reset





# -------------------------------------------------------------


set term postscript eps enhanced color 
set output 'plots/fp_S.eps'

load 'output/logR0_cutoff_plot_sersic.txt'
load 'output/fp_3rms_sersic.txt'
set xrange [ -0.3 : 1.5 ]
set yrange [ -0.3 : 1.5 ]
set table 'test.dat'
splot 'output/S_fp_map.txt'
unset table
set pointsize 2
set xtics font ", 20" 
set ytics font ", 20" 
set xrange [ -0.3 : 1.5 ]
set yrange [ -0.3 : 1.5 ]
set xtics 0.25
set ytics 0.25
set xlabel " log_1_0(R_0) " font  ",24"
set ylabel " a log_1_0({/Symbol s}_0) + b log_1_0(I_0) + c" font  ",24"
set key font ",20"
set key right
unset colorbox
set key bottom
set palette defined ( 0 '#FFFFFF',\
                      2 '#BBBBDD',\
                      4 '#9999BB',\
                      5 '#666688')
set arrow from R0_cut_sersic,-0.3 to R0_cut_sersic,1.5 nohead ls 1 lt 4 front
p 'test.dat' with image notitle,"output/scand_fp_sersic.txt" with points lt 0 pt 3 title "alt. candidates","output/taylor_fp_sersic.txt" with points lt 2 pt 9 title "  Ta10 sample","output/trujillo_fp_sersic.txt"  with points lt 5  pt 13 title " Tr09 sample","output/special_galaxy_FP_sersic.txt"   with points lt rgb '#445566' pt 5 title "b19", x lt 7 title 'fundamental plane', x+rms_sersic  lt 1 title "3- {/Symbol s} interval", x-rms_sersic  lt 1 notitle


reset
# -------------------------------------------------------------


set term postscript eps enhanced color 
set output 'plots/masses_dV.eps'


set xrange [ 10.2 : 12.5 ]
set yrange [ 10 : 12.0 ]
set table 'test.dat'
splot 'output/Mdyn_Mstar_dV_map.txt'
unset table
set pointsize 2
set xtics font ", 20" 
set ytics font ", 20" 
set xrange [ 10.2 : 12.5 ]
set yrange [ 10 : 12.0 ]
set xtics 0.5
set ytics 0.5
set xlabel " log_1_0(M_d_y_n [M_{{/=12 O}&{/*-.45 O}{/=12 \267}} ])" font  ",24"
set ylabel  " log_1_0(M_* [M_{{/=12 O}&{/*-.45 O}{/=12 \267}} ])" font  ",24"
set key font ",20"
set key right
unset colorbox
set key bottom
set palette defined ( 0 '#FFFFFF',\
                      2 '#BBBBDD',\
                      4 '#9999BB',\
                      5 '#666688')
p 'test.dat' with image notitle,"output/cand_mstar_mdyn_dV.txt" with points lt 0 pt 3 title "candidates","output/taylor_mstar_mdyn_dV.txt" with points lt 2 pt 9 title "  Ta10 sample","output/trujillo_mstar_mdyn_dV.txt"  with points lt 5  pt 13 title " Tr09 sample","output/vdsande2013_mdyn_mstar.txt" with points lt rgb "#ff8c00" pt 1 title "  van de Sande+ 2013","output/belli2014_mdyn_mstar.txt" with points lt 1 pt 2 title "  Belli+ 2014","output/zahid2015_mdyn_mstar.txt" with points lt 4 pt 6  title "  Zahid+ 2015","output/special_mstar_mdyn_dV.txt"   with points lt rgb '#445566' pt 5 title "b19", R0_cut ls 1 lt 4 notitle,x lt 7 notitle

reset



# -------------------------------------------------------------


set term postscript eps enhanced color  
set output 'plots/masses_S.eps'


set xrange [ 10.2 : 12.5 ]
set yrange [ 10 : 12.0 ]
set table 'test.dat'
splot 'output/Mdyn_Mstar_S_map.txt'
unset table
set pointsize 2
set xtics font ", 20" 
set ytics font ", 20" 
set xrange [ 10.2 : 12.5 ]
set yrange [ 10 : 12.0 ]
set xtics 0.5
set ytics 0.5
set xlabel " log_1_0(M_d_y_n [M_{{/=12 O}&{/*-.45 O}{/=12 \267}} ])" font  ",24"
set ylabel  " log_1_0(M_* [M_{{/=12 O}&{/*-.45 O}{/=12 \267}} ])" font  ",24"
set key font ",20"
set key right
unset colorbox
set key bottom
set palette defined ( 0 '#FFFFFF',\
                      2 '#BBBBDD',\
                      4 '#9999BB',\
                      5 '#666688')
p 'test.dat' with image notitle,"output/scand_mstar_mdyn_S.txt" with points lt 0 pt 3 title "alt. candidates","output/taylor_mstar_mdyn_S.txt" with points lt 2 pt 9 title "  Ta10 sample","output/trujillo_mstar_mdyn_S.txt"  with points lt 5  pt 13 title " Tr09 sample","output/special_mstar_mdyn_S.txt"   with points lt rgb '#445566' pt 5 title "b19", R0_cut ls 1 lt 4 notitle,x lt 7 notitle


reset






# -------------------------------------------------------------






set term postscript eps enhanced color 
set output 'plots/sigma_mstar_mdyn_dV.eps'


set xrange [ 2 : 2.69 ]
set yrange [ -0.3 : 0.8 ]
set table 'test.dat'
splot 'output/sigma_mstar_mdyn_dV_map.txt'
unset table
set xrange [ 2 : 2.69 ]
set yrange [ -0.3 : 0.8 ]
set pointsize 2
set xtics font ", 20" 
set ytics font ", 20" 
set xtics 0.1
set ytics 0.25
set xlabel " log_1_0({/Symbol s}_0 [km/s])" font  ",24"
set ylabel  " log_1_0(M_d_y_n/M_*)" font  ",24"
set key font ",20"
set key right
unset colorbox
set key bottom
set palette defined ( 0 '#FFFFFF',\
                      2 '#BBBBDD',\
                      4 '#9999BB',\
                      5 '#666688')
load 'output/logsigma0_cutoff_plot.txt'
s400=log10(400)
set arrow from sigma_cut,-0.3  to sigma_cut,0.8 nohead ls 1 lt 4 front
set arrow from s400,-0.3  to s400,0.8 nohead ls 1 lt 2 front

p 'test.dat' with image notitle,"output/cand_sigma_mstar_mdyn_dV.txt" with points lt 0 pt 3 title "candidates","output/taylor_sigma_mstar_mdyn_dV.txt" with points lt 2 pt 9 title "  Ta10 sample","output/trujillo_sigma_mstar_mdyn_dV.txt"  with points lt 5  pt 13 title " Tr09 sample","output/vdsande2013_sigma_mratio.txt" with points lt rgb "#ff8c00" pt 1 title "  van de Sande+ 2013","output/belli2014_sigma_mratio.txt" with points lt 1 pt 2 title "  Belli+ 2014","output/zahid2015_sigma_mratio.txt" with points lt 4 pt 6  title "  Zahid+ 2015","output/special_sigma_mstar_mdyn_dV.txt"   with points lt rgb '#445566' pt 5 title "b19",0 lt 7 notitle

unset arrow

reset





# -------------------------------------------------------------


set term postscript eps enhanced color 
set output 'plots/sigma_mstar_mdyn_S.eps'

set xrange [ 2 : 2.69 ]
set yrange [ -0.3 : 0.8 ]
set table 'test.dat'
splot 'output/sigma_mstar_mdyn_S_map.txt'
unset table
set pointsize 2
set xtics font ", 20" 
set ytics font ", 20" 
set xrange [ 2 : 2.69 ]
set yrange [ -0.3 : 0.8 ]
set xtics 0.1
set ytics 0.25
set xlabel " log_1_0({/Symbol s}_0 [km/s])" font  ",24"
set ylabel  " log_1_0(M_d_y_n/M_*)" font  ",24"
set key font ",20"
set key right
unset colorbox
set key bottom
set palette defined ( 0 '#FFFFFF',\
                      2 '#BBBBDD',\
                      4 '#9999BB',\
                      5 '#666688')
load 'output/logsigma0_cutoff_plot_sersic.txt'
set arrow from sigma_cut_sersic,-0.3  to sigma_cut_sersic,0.8 nohead ls 1 lt 4 front
p 'test.dat' with image notitle,"output/scand_sigma_mstar_mdyn_S.txt" with points lt 0 pt 3 title "   alt. candidates","output/taylor_sigma_mstar_mdyn_S.txt" with points lt 2 pt 9 title "  Ta10 sample","output/trujillo_sigma_mstar_mdyn_S.txt"  with points lt 5  pt 13 title " Tr09 sample","output/special_sigma_mstar_mdyn_S.txt"   with points lt rgb '#445566' pt 5 title "  b19",0 lt 7 notitle



reset



# -------------------------------------------------------------


set term postscript eps enhanced color
set output 'plots/M_star_vs_R0_S.eps'


load 'output/logR0_cutoff_plot_sersic.txt'


set xrange [ 10 : 12 ]
set yrange [ -0.3 : 1.5 ]
set table 'test.dat'
splot 'output/mstar_R0_S_map.txt'
unset table
set pointsize 2
set xtics font ", 20" 
set ytics font ", 20" 
set xrange [ 10 : 12 ]
set yrange [ -0.3 : 1.5 ]
set xtics 0.5
set ytics 0.25
set xlabel " log_1_0(M_* [M_{{/=12 O}&{/*-.45 O}{/=12 \267}} ]) " font  ",24"
set ylabel " log_1_0(R_0 [kpc])" font  ",24"
set key font ",20"
set key right
unset colorbox
set key bottom
set palette defined ( 0 '#FFFFFF',\
                      2 '#BBBBDD',\
                      4 '#9999BB',\
                      5 '#666688')
p 'test.dat' with image notitle,"output/scand_mstar_R0_S.txt" with points lt 0 pt 3 title "   alt. candidates","output/taylor_mstar_R0_S.txt" with points lt 2 pt 9 title "  Ta10 sample","output/trujillo_mstar_R0_S.txt"  with points lt 5  pt 13 title " Tr09 sample","output/special_mstar_R0_S.txt"   with points lt rgb '#445566' pt 5 title "  b19",R0_cut_sersic ls 1 lt 4 notitle


reset




# -------------------------------------------------------------



set term postscript eps enhanced color size 8in, 4in 
set output 'plots/all_fp_sersic.eps'
set multiplot layout 1,2


set tmargin at screen 0.99
set bmargin at screen 0.09
set lmargin at screen 0.09
set rmargin at screen 0.54

set xrange [-0.4:1.9]
set yrange [-0.4:1.9]
set isosample 350, 350
set table 'test.dat'
splot 'output/S_fp_map_used_g.txt'
unset table
set xrange [-0.4:1.9]
set yrange [-0.4:1.9]
unset key
set xtics font ", 20" 
set ytics font ", 20" 
set xlabel "log_1_0(R_0)" font  ",24"
set ylabel "a log_1_0({/Symbol s}_0) + b log_1_0(I_0) + c" font  ",24"
set xtics 0.5
set ytics 0.5
set mxtics 5
set mytics 5
unset colorbox
set label 1 "SDSS g band" at graph 0.05,0.9 font ',20' front
set palette defined ( 0 '#FFFFFF',\
                      1 '#000fff',\
                      2 '#0090ff',\
                      3 '#0fffee',\
                      4 '#90ff70',\
                      5 '#ffee00',\
                      6 '#ff7000',\
                      7 '#ee0000',\
                      8 '#7f0000')
p 'test.dat' with image, x lt 7

set tmargin at screen 0.99
set bmargin at screen 0.09
set lmargin at screen 0.54
set rmargin at screen 0.99

set xrange [-0.4:1.9]
set yrange [-0.4:1.9]
set isosample 350, 350
set table 'test.dat'
splot 'output/S_fp_map_used_r.txt'
unset table
set xtics font ", 20" 
set ytics font ", 20" 
set xrange [-0.4:1.9]
set yrange [-0.4:1.9]
unset key
set xlabel "log_1_0(R_0)" font  ",24"
unset ylabel 
set xtics 0.5
unset ytics 
set mxtics 5
set mytics 5
unset colorbox
set label 1 "SDSS r band" at graph 0.05,0.9 font ',20' front
set palette defined ( 0 '#FFFFFF',\
                      1 '#000fff',\
                      2 '#0090ff',\
                      3 '#0fffee',\
                      4 '#90ff70',\
                      5 '#ffee00',\
                      6 '#ff7000',\
                      7 '#ee0000',\
                      8 '#7f0000')
p 'test.dat' with image, x lt 7



unset multiplot
reset




# -------------------------------------------------------------




set term postscript eps enhanced color 
set output 'plots/M_star_vs_R0_otherdata.eps'
set size 1.5,1
load 'output/logR0_cutoff_plot.txt'


set xrange [ 10.4 : 11.8 ]
set yrange [ -0.2 : 1.1 ]
set table 'test.dat'
splot 'output/mstar_R0_dV_map.txt'
unset table
set pointsize 1.5
set xtics font ", 20" 
set ytics font ", 20" 
set xrange [ 10.4 : 11.8 ]
set yrange [ -0.2 : 1.1 ]
set xtics 0.25
set ytics 0.2
set xlabel " log_1_0(M_* [M_{{/=12 O}&{/*-.47 O}{/=12 \267}} ]) " font  ",24"
set ylabel " log_1_0(R_0 [kpc])" font  ",24"
set key font ",18"
set key outside
unset colorbox
set key top right
set key spacing 2.5
set palette defined ( 0 '#FFFFFF',\
                      2 '#BBBBDD',\
                      4 '#9999BB',\
                      5 '#666688')
set arrow from 10.4,R0_cut to 11.8,R0_cut nohead ls 1 lt 4 front
p 'test.dat' with image notitle,"output/cand_mstar_R0_dV.txt" with points lt 0 pt 3 title "  candidates (this paper)","output/taylor_mstar_R0_dV.txt" with points lt 2 pt 9 title "  Ta10 sample","output/trujillo_mstar_R0_dV.txt"  with points lt 5  pt 13 title " Tr09 sample","output/taylor2010_plot.txt" with points lt rgb '#008000' pt 8 title "  Taylor+ 2010", "output/trujillo2009_plot.txt" with points lt 3 pt 12 title "  Trujillo+ 2009" ,"output/vdsande2013_plot.txt" with points lt rgb "#ff8c00" pt 1 title "  van de Sande+ 2013","output/belli2014_plot.txt" with points lt 1 pt 2 title "  Belli+ 2014","output/damjanov2009_plot.txt" with points lt rgb "#CC3333" pt 10 title "  Damjanov+ 2009","output/zahid2015_plot.txt" with points lt 4 pt 6  title "  Zahid+ 2015","output/vdBosch2012_plot.txt"   with points lt rgb "violet" pt 7 title "  van den Bosch+ 2012","output/special_mstar_R0_dV.txt"   with points lt rgb '#445566' pt 5 title "  b19 (this paper)","input/lasker2013.txt"   with points lt rgb '#445566' pt 4 title "  b19 (Lasker+ 2013)"
reset



# -------------------------------------------------------------




set term postscript eps enhanced color 
set output 'plots/M_dyn_vs_R0_otherdata.eps'
set size 1.5,1
load 'output/logR0_cutoff_plot.txt'


set xrange [ 10.3 : 11.8 ]
set yrange [ -0.25 : 0.75 ]
set table 'test.dat'
splot 'output/R0_vs_M_dyn_map_dV.txt'
unset table
set pointsize 1.5
set xtics font ", 20" 
set ytics font ", 20" 
set xrange [ 10.3 : 11.8 ]
set yrange [ -0.25 : 0.75 ]
set xtics 0.25
set ytics 0.2
set xlabel " log_1_0(M_d_y_n [M_{{/=12 O}&{/*-.47 O}{/=12 \267}} ]) " font  ",24"
set ylabel " log_1_0(R_0 [kpc])" font  ",24"
set key font ",18"
set key outside
unset colorbox
set key top right
set key spacing 2.5
set palette defined ( 0 '#FFFFFF',\
                      2 '#BBBBDD',\
                      4 '#9999BB',\
                      5 '#666688')
set arrow from 10.3,R0_cut to 11.8,R0_cut nohead ls 1 lt 4 front
p 'test.dat' with image notitle,"output/cand_R0_vs_M_dyn.txt" with points lt 0 pt 3 title "  candidates (this paper)","output/taylor_R0_vs_M_dyn.txt" with points lt 2 pt 9 title "  Ta10 sample","output/trujillo_R0_vs_M_dyn.txt"  with points lt 5  pt 13 title " Tr09 sample","output/taylor2010_Mdyn.txt" with points lt rgb '#008000' pt 8 title "  Taylor+ 2010", "output/trujillo2009_Mdyn.txt" with points lt 3 pt 12 title "  Trujillo+ 2009" ,"output/vdsande2013_mdyn.txt" with points lt rgb "#ff8c00" pt 1 title "  van de Sande+ 2013","output/belli2014_mdyn.txt" with points lt 1 pt 2 title "  Belli+ 2014","output/zahid2015_Mdyn.txt" with points lt 4 pt 6  title "  Zahid+ 2015","output/vdbosch2012_Mdyn.txt"   with points lt rgb "violet" pt 7 title "  van den Bosch+ 2012","output/special_R0_vs_M_dyn.txt"   with points lt rgb '#445566' pt 5 title "  b19 (this paper)","output/lasker2013_Mdyn.txt"   with points lt rgb '#445566' pt 4 title "  b19 (Lasker+ 2013)"

reset




# -------------------------------------------------------------




set term postscript eps enhanced color 
set output 'plots/z_vs_size.eps'
set size 1.5,1
load 'output/logR0_cutoff_plot.txt'


set xrange [ 0.01 : 3 ]
set yrange [ -0.5 : 1.5 ]
set table 'test.dat'
splot 'output/z_vs_size_range.txt'
# splot 'output/z_vs_size.txt'
unset table
set pointsize 1.5
set xtics font ", 20" 
set ytics font ", 20" 
set xrange [ 0.01 : 3 ]
set yrange [ -0.5 : 1.5 ]
# set xtics 0.5
set ytics 0.2
set logscale x
set xlabel " redshift " font  ",24"
set ylabel " log_1_0(R_0 [kpc])" font  ",24"
set key font ",18"
set key outside
unset colorbox
set key spacing 2.5
set key top right
set palette defined ( 0 '#FFFFFF',\
                      2 '#BBBBDD',\
                      4 '#9999BB',\
                      5 '#666688')
set arrow from 0.01,R0_cut to 3,R0_cut nohead ls 1 lt 4 front
p 'test.dat' with image notitle,"output/cand_z_vs_size_range.txt" with points lt 0 pt 3 title "  candidates (this paper)","output/taylor_z_vs_size_range.txt" with points lt 2 pt 9 title "  Ta10 sample","output/trujillo_z_vs_size_range.txt"  with points lt 5  pt 13 title " Tr09 sample","output/taylor2010_z_vs_size_range.txt" with points lt rgb '#008000' pt 8 title "  Taylor+ 2010", "output/trujillo2009_z_vs_size_range.txt" with points lt 3 pt 12 title "  Trujillo+ 2009" ,"output/vdsande2013_z_dist_range.txt" with points lt rgb "#ff8c00" pt 1 title "  van de Sande+ 2013","output/belli2014_z_dist_range.txt" with points lt 1 pt 2 title "  Belli+ 2014","output/damjanov2009_z_vs_size_range.txt" with points lt rgb "#CC3333" pt 10 title "  Damjanov+ 2009","output/zahid2015_z_vs_size_range.txt" with points lt 4 pt 6  title "  Zahid+ 2015","output/vdBosch2012_z_vs_size.txt"   with points lt rgb "violet" pt 7 title "  van den Bosch+ 2012","output/special_z_vs_size.txt"   with points lt rgb '#445566' pt 5 title "  b19 (this paper)","output/limits_redshift_size.txt" with lines lt 1  lw 3 title " SDSS size limit" ,"output/candels_m1075_16limits.txt" with lines lt 2  lw 3 title "  size evolution lower mass" ,"output/candels_m1125_16limits.txt" with lines lt 3  lw 3 title "  size evolution high mass" 

reset



# -------------------------------------------------------------


